@@ -21,7 +21,7 @@ class LiveHelper(PRAWBase):
 
         .. code-block:: python
 
-            livethread = reddit.live('ukaeu1ik4sw5')
+            livethread = reddit.live("ukaeu1ik4sw5")
 
         :param id: A live thread ID, e.g., ``ukaeu1ik4sw5``.
         """
@@ -47,9 +47,9 @@ class LiveHelper(PRAWBase):
 
         .. code-block:: python
 
-            ids = ['3rgnbke2rai6hen7ciytwcxadi',
-                   'sw7bubeycai6hey4ciytwamw3a',
-                   't8jnufucss07']
+            ids = ["3rgnbke2rai6hen7ciytwcxadi",
+                   "sw7bubeycai6hey4ciytwamw3a",
+                   "t8jnufucss07"]
             for thread in reddit.live.info(ids)
                 print(thread.title)
 
@@ -114,12 +114,10 @@ class LiveHelper(PRAWBase):
 class MultiredditHelper(PRAWBase):
     """Provide a set of functions to interact with Multireddits."""
 
-    def __call__(
-        self, redditor: Union[str, Redditor], name: str
-    ) -> Multireddit:
+    def __call__(self, redditor: Union[str, Redditor], name: str) -> Multireddit:
         """Return a lazy instance of :class:`~.Multireddit`.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance who owns the multireddit.
         :param name: The name of the multireddit.
 
@@ -152,7 +150,7 @@ class MultiredditHelper(PRAWBase):
             ``sports``, ``style``, ``tech``, ``travel``, ``unusual stories``,
             ``video``, or ``None``.
         :param key_color: (Optional) RGB hex color code of the form
-            ``#FFFFFF``.
+            ``"#FFFFFF"``.
         :param visibility: (Optional) Can be one of: ``hidden``, ``private``,
             ``public`` (default: private).
         :param weighting_scheme: (Optional) Can be one of: ``classic``,
@@ -204,7 +202,7 @@ class SubredditHelper(PRAWBase):
 
         :param name: The name for the new subreddit.
 
-        :param title: The title of the subreddit. When ``None`` or ``''`` use
+        :param title: The title of the subreddit. When ``None`` or ``""`` use
             the value of ``name``.
 
         :param link_type: The types of submissions users can make.
