@@ -1,14 +1,15 @@
 """Provide the ListingGenerator class."""
 from copy import deepcopy
-from typing import Any, Dict, Iterator, Optional, TypeVar
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Union
 
 from ..base import PRAWBase
 from .listing import FlairListing
 
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
-class ListingGenerator(PRAWBase):
+class ListingGenerator(PRAWBase, Iterator):
     """Instances of this class generate :class:`.RedditBase` instances.
 
     .. warning:: This class should not be directly utilized. Instead you will
@@ -20,10 +21,10 @@ class ListingGenerator(PRAWBase):
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         url: str,
         limit: int = 100,
-        params: Optional[Dict[str, str]] = None,
+        params: Optional[Dict[str, Union[str, int]]] = None,
     ):
         """Initialize a ListingGenerator instance.
 
@@ -78,9 +79,7 @@ class ListingGenerator(PRAWBase):
         if not self._listing:
             raise StopIteration()
 
-        if self._listing.after and self._listing.after != self.params.get(
-            "after"
-        ):
+        if self._listing.after and self._listing.after != self.params.get("after"):
             self.params["after"] = self._listing.after
         else:
             self._exhausted = True
