@@ -1,5 +1,5 @@
 """Provide the BaseListingMixin class."""
-from typing import Any, Dict, Generator, Union
+from typing import Any, Dict, Iterator, Union
 from urllib.parse import urljoin
 
 from ...base import PRAWBase
@@ -33,7 +33,7 @@ class BaseListingMixin(PRAWBase):
         self,
         time_filter: str = "all",
         **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for controversial submissions.
 
         :param time_filter: Can be one of: all, day, hour, month, week, year
@@ -48,12 +48,12 @@ class BaseListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           reddit.domain('imgur.com').controversial('week')
-           reddit.multireddit('samuraisam', 'programming').controversial('day')
-           reddit.redditor('spez').controversial('month')
-           reddit.redditor('spez').comments.controversial('year')
-           reddit.redditor('spez').submissions.controversial('all')
-           reddit.subreddit('all').controversial('hour')
+           reddit.domain("imgur.com").controversial("week")
+           reddit.multireddit("samuraisam", "programming").controversial("day")
+           reddit.redditor("spez").controversial("month")
+           reddit.redditor("spez").comments.controversial("year")
+           reddit.redditor("spez").submissions.controversial("all")
+           reddit.subreddit("all").controversial("hour")
 
         """
         self._validate_time_filter(time_filter)
@@ -61,9 +61,7 @@ class BaseListingMixin(PRAWBase):
         url = _prepare(self, generator_kwargs, "controversial")
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def hot(
-        self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    def hot(self, **generator_kwargs: Union[str, int, Dict[str, str]]) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for hot items.
 
         Additional keyword arguments are passed in the initialization of
@@ -73,21 +71,19 @@ class BaseListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           reddit.domain('imgur.com').hot()
-           reddit.multireddit('samuraisam', 'programming').hot()
-           reddit.redditor('spez').hot()
-           reddit.redditor('spez').comments.hot()
-           reddit.redditor('spez').submissions.hot()
-           reddit.subreddit('all').hot()
+           reddit.domain("imgur.com").hot()
+           reddit.multireddit("samuraisam", "programming").hot()
+           reddit.redditor("spez").hot()
+           reddit.redditor("spez").comments.hot()
+           reddit.redditor("spez").submissions.hot()
+           reddit.subreddit("all").hot()
 
         """
         generator_kwargs.setdefault("params", {})
         url = _prepare(self, generator_kwargs, "hot")
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def new(
-        self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    def new(self, **generator_kwargs: Union[str, int, Dict[str, str]]) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for new items.
 
         Additional keyword arguments are passed in the initialization of
@@ -97,12 +93,12 @@ class BaseListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           reddit.domain('imgur.com').new()
-           reddit.multireddit('samuraisam', 'programming').new()
-           reddit.redditor('spez').new()
-           reddit.redditor('spez').comments.new()
-           reddit.redditor('spez').submissions.new()
-           reddit.subreddit('all').new()
+           reddit.domain("imgur.com").new()
+           reddit.multireddit("samuraisam", "programming").new()
+           reddit.redditor("spez").new()
+           reddit.redditor("spez").comments.new()
+           reddit.redditor("spez").submissions.new()
+           reddit.subreddit("all").new()
 
         """
         generator_kwargs.setdefault("params", {})
@@ -113,7 +109,7 @@ class BaseListingMixin(PRAWBase):
         self,
         time_filter: str = "all",
         **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for top submissions.
 
         :param time_filter: Can be one of: all, day, hour, month, week, year
@@ -128,12 +124,12 @@ class BaseListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           reddit.domain('imgur.com').top('week')
-           reddit.multireddit('samuraisam', 'programming').top('day')
-           reddit.redditor('spez').top('month')
-           reddit.redditor('spez').comments.top('year')
-           reddit.redditor('spez').submissions.top('all')
-           reddit.subreddit('all').top('hour')
+           reddit.domain("imgur.com").top("week")
+           reddit.multireddit("samuraisam", "programming").top("day")
+           reddit.redditor("spez").top("month")
+           reddit.redditor("spez").comments.top("year")
+           reddit.redditor("spez").submissions.top("all")
+           reddit.subreddit("all").top("hour")
 
         """
         self._validate_time_filter(time_filter)
