@@ -1,5 +1,5 @@
 """Provide Collections functionality."""
-from typing import Any, Dict, Generator, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, List, Optional, Union
 
 from ...const import API_PATH
 from ...exceptions import ClientException
@@ -9,9 +9,8 @@ from .base import RedditBase
 from .submission import Submission
 from .subreddit import Subreddit
 
-Reddit = TypeVar("Reddit")
-_CollectionModeration = TypeVar("_CollectionModeration")
-_SubredditCollectionsModeration = TypeVar("_SubredditCollectionsModeration")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class Collection(RedditBase):
@@ -21,13 +20,13 @@ class Collection(RedditBase):
 
     .. code-block:: python
 
-       collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
+       collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
 
     or
 
     .. code-block:: python
 
-       collection = reddit.subreddit('SUBREDDIT').collections(
+       collection = reddit.subreddit("SUBREDDIT").collections(
            permalink='https://reddit.com/r/SUBREDDIT/collection/some_uuid')
 
     **Typical Attributes**
@@ -62,7 +61,7 @@ class Collection(RedditBase):
     STR_FIELD = "collection_id"
 
     @cachedproperty
-    def mod(self) -> _CollectionModeration:
+    def mod(self) -> "CollectionModeration":
         """Get an instance of :class:`.CollectionModeration`.
 
         Provides access to various methods, including
@@ -75,8 +74,8 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
-           collection.mod.update_title('My new title!')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
+           collection.mod.update_title("My new title!")
 
         """
         return CollectionModeration(self._reddit, self.collection_id)
@@ -89,7 +88,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-            collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
+            collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
             subreddit = collection.subreddit
 
         """
@@ -97,7 +96,7 @@ class Collection(RedditBase):
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         _data: Dict[str, Any] = None,
         collection_id: Optional[str] = None,
         permalink: Optional[str] = None,
@@ -113,8 +112,7 @@ class Collection(RedditBase):
 
         if (_data, collection_id, permalink).count(None) != 2:
             raise TypeError(
-                "Exactly one of _data, collection_id, "
-                "or permalink must be provided."
+                "Exactly one of _data, collection_id, or permalink must be provided."
             )
 
         if permalink is not None:
@@ -135,7 +133,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
            for submission in collection:
                print(submission.title, submission.permalink)
 
@@ -150,7 +148,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
            print(len(collection))
 
         """
@@ -196,7 +194,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit('SUBREDDIT').collections('some_uuid').follow()
+           reddit.subreddit("SUBREDDIT").collections("some_uuid").follow()
 
         .. seealso:: :meth:`~.unfollow`
         """
@@ -212,7 +210,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit('SUBREDDIT').collections('some_uuid').unfollow()
+           reddit.subreddit("SUBREDDIT").collections("some_uuid").unfollow()
 
         .. seealso:: :meth:`~.follow`
         """
@@ -229,7 +227,7 @@ class CollectionModeration(PRAWBase):
 
     .. code-block:: python
 
-       reddit.subreddit('SUBREDDIT').collections('some_uuid').mod
+       reddit.subreddit("SUBREDDIT").collections("some_uuid").mod
     """
 
     def _post_fullname(self, post):
@@ -242,20 +240,16 @@ class CollectionModeration(PRAWBase):
             return post.fullname
         elif not isinstance(post, str):
             raise TypeError(
-                "Cannot get fullname from object of type {}.".format(
-                    type(post)
-                )
+                "Cannot get fullname from object of type {}.".format(type(post))
             )
-        if post.startswith(
-            "{}_".format(self._reddit.config.kinds["submission"])
-        ):
+        if post.startswith("{}_".format(self._reddit.config.kinds["submission"])):
             return post
         try:
             return self._reddit.submission(url=post).fullname
         except ClientException:
             return self._reddit.submission(id=post).fullname
 
-    def __init__(self, reddit: Reddit, collection_id: str):
+    def __init__(self, reddit: "Reddit", collection_id: str):
         """Initialize an instance of CollectionModeration.
 
         :param collection_id: The ID of a collection.
@@ -263,7 +257,7 @@ class CollectionModeration(PRAWBase):
         super().__init__(reddit, _data=None)
         self.collection_id = collection_id
 
-    def add_post(self, submission: Submission):
+    def add_post(self, submission: "Submission"):
         """Add a post to the collection.
 
         :param submission: The post to add, a :class:`.Submission`, its
@@ -274,8 +268,8 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
-           collection.mod.add_post('bgibu9')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
+           collection.mod.add_post("bgibu9")
 
         .. seealso:: :meth:`.remove_post`
 
@@ -284,10 +278,7 @@ class CollectionModeration(PRAWBase):
 
         self._reddit.post(
             API_PATH["collection_add_post"],
-            data={
-                "collection_id": self.collection_id,
-                "link_fullname": link_fullname,
-            },
+            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
         )
 
     def delete(self):
@@ -297,17 +288,16 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           reddit.subreddit('SUBREDDIT').collections('some_uuid').mod.delete()
+           reddit.subreddit("SUBREDDIT").collections("some_uuid").mod.delete()
 
         .. seealso:: :meth:`~.SubredditCollectionsModeration.create`
 
         """
         self._reddit.post(
-            API_PATH["collection_delete"],
-            data={"collection_id": self.collection_id},
+            API_PATH["collection_delete"], data={"collection_id": self.collection_id},
         )
 
-    def remove_post(self, submission: Submission):
+    def remove_post(self, submission: "Submission"):
         """Remove a post from the collection.
 
         :param submission: The post to remove, a :class:`.Submission`, its
@@ -318,8 +308,8 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
-           collection.mod.remove_post('bgibu9')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
+           collection.mod.remove_post("bgibu9")
 
         .. seealso:: :meth:`.add_post`
 
@@ -328,10 +318,7 @@ class CollectionModeration(PRAWBase):
 
         self._reddit.post(
             API_PATH["collection_remove_post"],
-            data={
-                "collection_id": self.collection_id,
-                "link_fullname": link_fullname,
-            },
+            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
         )
 
     def reorder(self, links: List[Union[str, Submission]]):
@@ -344,7 +331,7 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
            current_order = collection.link_ids
            new_order = reversed(current_order)
            collection.mod.reorder(new_order)
@@ -365,18 +352,15 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
-           collection.mod.update_description('Please enjoy these links!')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
+           collection.mod.update_description("Please enjoy these links!")
 
         .. seealso:: :meth:`.update_title`
 
         """
         self._reddit.post(
             API_PATH["collection_desc"],
-            data={
-                "collection_id": self.collection_id,
-                "description": description,
-            },
+            data={"collection_id": self.collection_id, "description": description},
         )
 
     def update_title(self, title: str):
@@ -388,8 +372,8 @@ class CollectionModeration(PRAWBase):
 
         .. code-block:: python
 
-           collection = reddit.subreddit('SUBREDDIT').collections('some_uuid')
-           collection.mod.update_title('Titley McTitleface')
+           collection = reddit.subreddit("SUBREDDIT").collections("some_uuid")
+           collection.mod.update_title("Titley McTitleface")
 
         .. seealso:: :meth:`.update_description`
 
@@ -407,30 +391,26 @@ class SubredditCollections(PRAWBase):
 
     .. code-block:: python
 
-       reddit.subreddit('SUBREDDIT').collections
+       reddit.subreddit("SUBREDDIT").collections
 
     """
 
     @cachedproperty
-    def mod(self) -> _SubredditCollectionsModeration:
+    def mod(self) -> "SubredditCollectionsModeration":
         """Get an instance of :class:`.SubredditCollectionsModeration`.
 
         Provides :meth:`~SubredditCollectionsModeration.create`:
 
         .. code-block:: python
 
-           my_sub = reddit.subreddit('SUBREDDIT')
-           new_collection = my_sub.collections.mod.create('Title', 'desc')
+           my_sub = reddit.subreddit("SUBREDDIT")
+           new_collection = my_sub.collections.mod.create("Title", "desc")
 
         """
-        return SubredditCollectionsModeration(
-            self._reddit, self.subreddit.fullname
-        )
+        return SubredditCollectionsModeration(self._reddit, self.subreddit.fullname)
 
     def __call__(
-        self,
-        collection_id: Optional[str] = None,
-        permalink: Optional[str] = None,
+        self, collection_id: Optional[str] = None, permalink: Optional[str] = None,
     ):
         """Return the :class:`.Collection` with the specified ID.
 
@@ -444,9 +424,9 @@ class SubredditCollections(PRAWBase):
 
         .. code-block:: python
 
-           subreddit = reddit.subreddit('SUBREDDIT')
+           subreddit = reddit.subreddit("SUBREDDIT")
 
-           uuid = '847e4548-a3b5-4ad7-afb4-edbfc2ed0a6b'
+           uuid = "847e4548-a3b5-4ad7-afb4-edbfc2ed0a6b"
            collection = subreddit.collections(uuid)
            print(collection.title)
            print(collection.description)
@@ -459,8 +439,7 @@ class SubredditCollections(PRAWBase):
         """
         if (collection_id is None) == (permalink is None):
             raise TypeError(
-                "Exactly one of collection_id or permalink must "
-                "be provided."
+                "Exactly one of collection_id or permalink must be provided."
             )
         return Collection(
             self._reddit, collection_id=collection_id, permalink=permalink
@@ -468,8 +447,8 @@ class SubredditCollections(PRAWBase):
 
     def __init__(
         self,
-        reddit: Reddit,
-        subreddit: Subreddit,
+        reddit: "Reddit",
+        subreddit: "Subreddit",
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Initialize an instance of SubredditCollections."""
@@ -483,7 +462,7 @@ class SubredditCollections(PRAWBase):
 
         .. code-block:: python
 
-           for collection in reddit.subreddit('SUBREDDIT').collections:
+           for collection in reddit.subreddit("SUBREDDIT").collections:
                print(collection.permalink)
 
         """
@@ -502,13 +481,13 @@ class SubredditCollectionsModeration(PRAWBase):
 
     .. code-block:: python
 
-       reddit.subreddit('SUBREDDIT').collections.mod
+       reddit.subreddit("SUBREDDIT").collections.mod
 
     """
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         sub_fullname: str,
         _data: Optional[Dict[str, Any]] = None,
     ):
@@ -531,9 +510,9 @@ class SubredditCollectionsModeration(PRAWBase):
 
         .. code-block:: python
 
-           my_sub = reddit.subreddit('SUBREDDIT')
-           new_collection = my_sub.collections.mod.create('Title', 'desc')
-           new_collection.mod.add_post('bgibu9')
+           my_sub = reddit.subreddit("SUBREDDIT")
+           new_collection = my_sub.collections.mod.create("Title", "desc")
+           new_collection.mod.add_post("bgibu9")
 
         .. seealso:: :meth:`~CollectionModeration.delete`
 
