@@ -1,5 +1,5 @@
 """Provide the Comment class."""
-from typing import Any, Dict, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Optional, Union
 
 from ...const import API_PATH
 from ...exceptions import ClientException, InvalidURL
@@ -14,11 +14,10 @@ from .mixins import (
 )
 from .redditor import Redditor
 
-_Comment = TypeVar("_Comment")
-_CommentModeration = TypeVar("_CommentModeration")
-Reddit = TypeVar("Reddit")
-Submission = TypeVar("Submission")
-Subreddit = TypeVar("Subreddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
+    from .submission import Submission
+    from .subreddit import Subreddit  # noqa: F401
 
 
 class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
@@ -30,7 +29,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    comprehensive in any way.
+    necessarily complete.
 
     ======================= ===================================================
     Attribute               Description
@@ -65,9 +64,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
     """
 
-    MISSING_COMMENT_MESSAGE = (
-        "This comment does not appear to be in the comment tree"
-    )
+    MISSING_COMMENT_MESSAGE = "This comment does not appear to be in the comment tree"
     STR_FIELD = "id"
 
     @staticmethod
@@ -84,7 +81,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         return parts[-1]
 
     @property
-    def _kind(self):
+    def _kind(self) -> str:
         """Return the class's kind."""
         return self._reddit.config.kinds["comment"]
 
@@ -95,14 +92,14 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         return parent_type == self._reddit.config.kinds["submission"]
 
     @cachedproperty
-    def mod(self) -> _CommentModeration:
+    def mod(self) -> "CommentModeration":
         """Provide an instance of :class:`.CommentModeration`.
 
         Example usage:
 
         .. code-block:: python
 
-            comment = reddit.comment('dkk4qjd')
+            comment = reddit.comment("dkk4qjd")
             comment.mod.approve()
 
         """
@@ -121,7 +118,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         .. code-block:: python
 
-           comment.reply_sort = 'new'
+           comment.reply_sort = "new"
            comment.refresh()
            replies = comment.replies
 
@@ -135,18 +132,16 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         return self._replies
 
     @property
-    def submission(self) -> Submission:
+    def submission(self) -> "Submission":
         """Return the Submission object this comment belongs to."""
         if not self._submission:  # Comment not from submission
-            self._submission = self._reddit.submission(
-                self._extract_submission_id()
-            )
+            self._submission = self._reddit.submission(self._extract_submission_id())
         return self._submission
 
     @submission.setter
-    def submission(self, submission: Submission):
+    def submission(self, submission: "Submission"):
         """Update the Submission associated with the Comment."""
-        submission._comments_by_id[self.name] = self
+        submission._comments_by_id[self.fullname] = self
         self._submission = submission
         # pylint: disable=not-an-iterable
         for reply in getattr(self, "replies", []):
@@ -154,16 +149,14 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         url: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the Comment object."""
         if (id, url, _data).count(None) != 2:
-            raise TypeError(
-                "Exactly one of `id`, `url`, or `_data` must be provided."
-            )
+            raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
         self._replies = []
         self._submission = None
         super().__init__(reddit, _data=_data)
@@ -177,7 +170,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     def __setattr__(
         self,
         attribute: str,
-        value: Union[str, Redditor, CommentForest, Subreddit],
+        value: Union[str, "Redditor", "CommentForest", "Subreddit"],
     ):
         """Objectify author, replies, and subreddit."""
         if attribute == "author":
@@ -206,9 +199,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         if not data["children"]:
             raise ClientException(
-                "No data returned for comment {}".format(
-                    self.__class__.__name__, self.fullname
-                )
+                "No data returned for comment {}".format(self.fullname)
             )
 
         comment_data = data["children"][0]["data"]
@@ -221,7 +212,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
             return self.context.rsplit("/", 4)[1]
         return self.link_id.split("_", 1)[1]
 
-    def parent(self) -> Union[_Comment, Submission]:
+    def parent(self) -> Union["Comment", "Submission"]:
         """Return the parent of the comment.
 
         The returned parent will be an instance of either
@@ -230,7 +221,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         If this comment was obtained through a :class:`.Submission`, then its
         entire ancestry should be immediately available, requiring no extra
         network requests. However, if this comment was obtained through other
-        means, e.g., ``reddit.comment('COMMENT_ID')``, or
+        means, e.g., ``reddit.comment("COMMENT_ID")``, or
         ``reddit.inbox.comment_replies``, then the returned parent may be a
         lazy instance of either :class:`.Comment`, or :class:`.Submission`.
 
@@ -238,7 +229,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         .. code-block:: python
 
-           comment = reddit.comment('cklhv0f')
+           comment = reddit.comment("cklhv0f")
            parent = comment.parent()
            # `replies` is empty until the comment is refreshed
            print(parent.replies)  # Output: []
@@ -257,7 +248,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         .. code-block:: python
 
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            ancestor = comment
            refresh_counter = 0
            while not ancestor.is_root:
@@ -295,7 +286,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
         .. code-block:: python
 
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            comment.refresh()
 
         """
@@ -311,9 +302,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
             params["limit"] = self.reply_limit
         if "reply_sort" in self.__dict__:
             params["sort"] = self.reply_sort
-        comment_list = self._reddit.get(comment_path, params=params)[
-            1
-        ].children
+        comment_list = self._reddit.get(comment_path, params=params)[1].children
         if not comment_list:
             raise ClientException(self.MISSING_COMMENT_MESSAGE)
 
@@ -344,14 +333,14 @@ class CommentModeration(ThingModerationMixin):
 
     .. code-block:: python
 
-       comment = reddit.comment('dkk4qjd')
+       comment = reddit.comment("dkk4qjd")
        comment.mod.approve()
 
     """
 
     REMOVAL_MESSAGE_API = "removal_comment_message"
 
-    def __init__(self, comment: Comment):
+    def __init__(self, comment: "Comment"):
         """Create a CommentModeration instance.
 
         :param comment: The comment to moderate.
@@ -367,7 +356,7 @@ class CommentModeration(ThingModerationMixin):
         .. code-block:: python
 
            # lock a comment:
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            comment.mod.show()
         """
         url = API_PATH["show_comment"]
