@@ -1,20 +1,18 @@
 """Provide the LiveThread class."""
-from typing import Any, Dict, Generator, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
 from ..list.redditor import RedditorList
 from ..listing.generator import ListingGenerator
+from ..util import stream_generator
 from .base import RedditBase
 from .mixins import FullnameMixin
 from .redditor import Redditor
 
-_LiveThread = TypeVar("_LiveThread")
-_LiveThreadContribution = TypeVar("_LiveThreadContribution")
-_LiveUpdate = TypeVar("_LiveUpdate")
-_LiveUpdateContribution = TypeVar("_LiveUpdateContribution")
-Reddit = TypeVar("Reddit")
-Submission = TypeVar("Submission")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
+    from .submission import Submission  # noqa: F401
 
 
 class LiveContributorRelationship:
@@ -35,7 +33,7 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
+           thread = reddit.live("ukaeu1ik4sw5")
            for contributor in thread.contributor():
                print(contributor)
 
@@ -44,7 +42,7 @@ class LiveContributorRelationship:
         temp = self.thread._reddit.get(url)
         return temp if isinstance(temp, RedditorList) else temp[0]
 
-    def __init__(self, thread: _LiveThread):
+    def __init__(self, thread: "LiveThread"):
         """Create a :class:`.LiveContributorRelationship` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
@@ -63,7 +61,7 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-            thread = reddit.live('ydwwxneu7vsa')
+            thread = reddit.live("ydwwxneu7vsa")
             thread.contributor.accept_invite()
 
         """
@@ -71,30 +69,27 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url)
 
     def invite(
-        self,
-        redditor: Union[str, Redditor],
-        permissions: Optional[List[str]] = None,
+        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
     ):
         """Invite a redditor to be a contributor of the live thread.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should
             be a list of strings specifying which subset of permissions to
             grant. An empty list ``[]`` indicates no permissions, and when
             not provided (``None``), indicates full permissions.
-        :raises: :class:`praw.exceptions.RedditAPIException` if the invitation
-            already exists.
+        :raises: :class:`.RedditAPIException` if the invitation already exists.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           redditor = reddit.redditor('spez')
+           thread = reddit.live("ukaeu1ik4sw5")
+           redditor = reddit.redditor("spez")
 
-           # 'manage' and 'settings' permissions
-           thread.contributor.invite(redditor, ['manage', 'settings'])
+           # "manage" and "settings" permissions
+           thread.contributor.invite(redditor, ["manage", "settings"])
 
         .. seealso:: :meth:`.LiveContributorRelationship.remove_invite` to
             remove the invite for redditor.
@@ -115,7 +110,7 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-            thread = reddit.live('ydwwxneu7vsa')
+            thread = reddit.live("ydwwxneu7vsa")
             thread.contributor.leave()
 
         """
@@ -125,17 +120,17 @@ class LiveContributorRelationship:
     def remove(self, redditor: Union[str, Redditor]):
         """Remove the redditor from the live thread contributors.
 
-        :param redditor: A redditor fullname (e.g., ``t2_1w72``) or
+        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
             :class:`~.Redditor` instance.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           redditor = reddit.redditor('spez')
+           thread = reddit.live("ukaeu1ik4sw5")
+           redditor = reddit.redditor("spez")
            thread.contributor.remove(redditor)
-           thread.contributor.remove('t2_1w72')  # with fullname
+           thread.contributor.remove("t2_1w72")  # with fullname
 
         """
         if isinstance(redditor, Redditor):
@@ -149,17 +144,17 @@ class LiveContributorRelationship:
     def remove_invite(self, redditor: Union[str, Redditor]):
         """Remove the invite for redditor.
 
-        :param redditor: A redditor fullname (e.g., ``t2_1w72``) or
+        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
             :class:`~.Redditor` instance.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           redditor = reddit.redditor('spez')
+           thread = reddit.live("ukaeu1ik4sw5")
+           redditor = reddit.redditor("spez")
            thread.contributor.remove_invite(redditor)
-           thread.contributor.remove_invite('t2_1w72')  # with fullname
+           thread.contributor.remove_invite("t2_1w72")  # with fullname
 
         .. seealso:: :meth:`.LiveContributorRelationship.invite` to
             invite a redditor to be a contributor of the live thread.
@@ -174,13 +169,11 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url, data=data)
 
     def update(
-        self,
-        redditor: Union[str, Redditor],
-        permissions: Optional[List[str]] = None,
+        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
     ):
         """Update the contributor permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should
             be a list of strings specifying which subset of permissions to
@@ -192,21 +185,21 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           thread.contributor.update('spez')
+           thread = reddit.live("ukaeu1ik4sw5")
+           thread.contributor.update("spez")
 
-        To grant 'access' and 'edit' permissions (and to remove other
-        permissions), try:
+        To grant ``"access"`` and ``"edit"`` permissions (and to
+        remove other permissions), try:
 
         .. code-block:: python
 
-           thread.contributor.update('spez', ['access', 'edit'])
+           thread.contributor.update("spez", ["access", "edit"])
 
         To remove all permissions from the contributor, try:
 
         .. code-block:: python
 
-           subreddit.moderator.update('spez', [])
+           subreddit.moderator.update("spez", [])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -218,13 +211,11 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url, data=data)
 
     def update_invite(
-        self,
-        redditor: Union[str, Redditor],
-        permissions: Optional[List[str]] = None,
+        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
     ):
         """Update the contributor invite permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should
             be a list of strings specifying which subset of permissions to
@@ -236,21 +227,21 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           thread.contributor.update_invite('spez')
+           thread = reddit.live("ukaeu1ik4sw5")
+           thread.contributor.update_invite("spez")
 
-        To set 'access' and 'edit' permissions (and to remove other
+        To set "access" and "edit" permissions (and to remove other
         permissions) to the invitation, try:
 
         .. code-block:: python
 
-           thread.contributor.update_invite('spez', ['access', 'edit'])
+           thread.contributor.update_invite("spez", ["access", "edit"])
 
         To remove all permissions from the invitation, try:
 
         .. code-block:: python
 
-           thread.contributor.update_invite('spez', [])
+           thread.contributor.update_invite("spez", [])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -271,7 +262,7 @@ class LiveThread(RedditBase):
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    necessarily comprehensive.
+    necessarily complete.
 
     ======================= ===================================================
     Attribute               Description
@@ -291,15 +282,15 @@ class LiveThread(RedditBase):
     STR_FIELD = "id"
 
     @cachedproperty
-    def contrib(self) -> _LiveThreadContribution:
+    def contrib(self) -> "LiveThreadContribution":
         """Provide an instance of :class:`.LiveThreadContribution`.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           thread.contrib.add('### update')
+           thread = reddit.live("ukaeu1ik4sw5")
+           thread.contrib.add("### update")
 
         """
         return LiveThreadContribution(self)
@@ -315,15 +306,41 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
+           thread = reddit.live("ukaeu1ik4sw5")
            for contributor in thread.contributor():
-               # prints `(Redditor(name='Acidtwist'), [u'all'])`
+               # prints `(Redditor(name="Acidtwist"), ["all"])`
                print(contributor, contributor.permissions)
 
         """
         return LiveContributorRelationship(self)
 
-    def __eq__(self, other: Union[str, _LiveThread]) -> bool:
+    @cachedproperty
+    def stream(self) -> "LiveThreadStream":
+        """Provide an instance of :class:`.LiveThreadStream`.
+
+        Streams are used to indefinitely retrieve new updates made to a
+        live thread, like:
+
+        .. code-block:: python
+
+            for live_update in reddit.live("ta535s1hq2je").stream.updates():
+                print(live_update.body)
+
+        Updates are yielded oldest first as :class:`.LiveUpdate`. Up to 100
+        historical updates will initially be returned.
+        To only retrieve new updates starting from when the stream is
+        created, pass ``skip_existing=True``:
+
+        .. code-block:: python
+
+            live_thread = reddit.live("ta535s1hq2je")
+            for live_update in live_thread.stream.updates(skip_existing=True):
+                print(live_update.author)
+
+        """
+        return LiveThreadStream(self)
+
+    def __eq__(self, other: Union[str, "LiveThread"]) -> bool:
         """Return whether the other instance equals the current.
 
         .. note:: This comparison is case sensitive.
@@ -332,21 +349,21 @@ class LiveThread(RedditBase):
             return other == str(self)
         return isinstance(other, self.__class__) and str(self) == str(other)
 
-    def __getitem__(self, update_id: str) -> _LiveUpdate:
+    def __getitem__(self, update_id: str) -> "LiveUpdate":
         """Return a lazy :class:`.LiveUpdate` instance.
 
         :param update_id: A live update ID, e.g.,
-            ``7827987a-c998-11e4-a0b9-22000b6a88d2``.
+            ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           update = thread['7827987a-c998-11e4-a0b9-22000b6a88d2']
-           update.thread     # LiveThread(id='ukaeu1ik4sw5')
-           update.id         # '7827987a-c998-11e4-a0b9-22000b6a88d2'
-           update.author     # 'umbrae'
+           thread = reddit.live("ukaeu1ik4sw5")
+           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
+           update.thread     # LiveThread(id="ukaeu1ik4sw5")
+           update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+           update.author     # "umbrae"
         """
         return LiveUpdate(self._reddit, self.id, update_id)
 
@@ -356,16 +373,14 @@ class LiveThread(RedditBase):
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         id: Optional[str] = None,
-        _data: Optional[
-            Dict[str, Any]
-        ] = None,  # pylint: disable=redefined-builtin
+        _data: Optional[Dict[str, Any]] = None,  # pylint: disable=redefined-builtin
     ):
         """Initialize a lazy :class:`.LiveThread` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
-        :param id: A live thread ID, e.g., ``ukaeu1ik4sw5``
+        :param id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``
         """
         if bool(id) == bool(_data):
             raise TypeError("Either `id` or `_data` must be provided.")
@@ -390,7 +405,7 @@ class LiveThread(RedditBase):
 
     def discussions(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Submission, None, None]:
+    ) -> Iterator["Submission"]:
         """Get submissions linking to the thread.
 
         :param generator_kwargs: keyword arguments passed to
@@ -405,7 +420,7 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
+           thread = reddit.live("ukaeu1ik4sw5")
            for submission in thread.discussions(limit=None):
                print(submission.title)
 
@@ -416,16 +431,16 @@ class LiveThread(RedditBase):
     def report(self, type: str):  # pylint: disable=redefined-builtin
         """Report the thread violating the Reddit rules.
 
-        :param type: One of ``spam``, ``vote-manipulation``,
-            ``personal-information``, ``sexualizing-minors``,
-            ``site-breaking``.
+        :param type: One of ``"spam"``, ``"vote-manipulation"``,
+            ``"personal-information"``, ``"sexualizing-minors"``,
+            ``"site-breaking"``.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('xyu8kmjvfrww')
-           thread.report('spam')
+           thread = reddit.live("xyu8kmjvfrww")
+           thread.report("spam")
 
         """
         url = API_PATH["live_report"].format(id=self.id)
@@ -433,7 +448,7 @@ class LiveThread(RedditBase):
 
     def updates(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[_LiveUpdate, None, None]:
+    ) -> Iterator["LiveUpdate"]:
         """Return a :class:`.ListingGenerator` yields :class:`.LiveUpdate` s.
 
         :param generator_kwargs: keyword arguments passed to
@@ -448,9 +463,9 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           after = 'LiveUpdate_fefb3dae-7534-11e6-b259-0ef8c7233633'
-           for submission in thread.updates(limit=5, params={'after': after}):
+           thread = reddit.live("ukaeu1ik4sw5")
+           after = "LiveUpdate_fefb3dae-7534-11e6-b259-0ef8c7233633"
+           for submission in thread.updates(limit=5, params={"after": after}):
                print(submission.body)
 
         """
@@ -473,8 +488,8 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           thread.contrib.add('### update')
+           thread = reddit.live("ukaeu1ik4sw5")
+           thread.contrib.add("### update")
 
         """
         self.thread = thread
@@ -488,8 +503,8 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('ydwwxneu7vsa')
-           thread.contrib.add('test `LiveThreadContribution.add()`')
+           thread = reddit.live("ydwwxneu7vsa")
+           thread.contrib.add("test `LiveThreadContribution.add()`")
 
         """
         url = API_PATH["live_add_update"].format(id=self.thread.id)
@@ -502,7 +517,7 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
+           thread = reddit.live("ukaeu1ik4sw5")
            thread.contrib.close()
 
         """
@@ -538,7 +553,7 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('xyu8kmjvfrww')
+           thread = reddit.live("xyu8kmjvfrww")
 
            # update `title` and `nsfw`
            updated_thread = thread.contrib.update(title=new_title, nsfw=True)
@@ -574,6 +589,60 @@ class LiveThreadContribution:
         self.thread._reset_attributes(*data.keys())
 
 
+class LiveThreadStream:
+    """Provides a :class:`.LiveThread` stream.
+
+    Usually used via:
+
+    .. code-block:: python
+
+        for live_update in reddit.live("ta535s1hq2je").stream.updates():
+            print(live_update.body)
+
+    """
+
+    def __init__(self, live_thread: LiveThread):
+        """Create a LiveThreadStream instance.
+
+        :param live_thread: The live thread associated with the stream.
+        """
+        self.live_thread = live_thread
+
+    def updates(self, **stream_options: Dict[str, Any]) -> Iterator["LiveUpdate"]:
+        """Yield new updates to the live thread as they become available.
+
+        :param skip_existing: Set to ``True`` to only fetch items created
+            after the stream (default: ``False``).
+
+        As with :meth:`.LiveThread.updates()`, updates are yielded as
+        :class:`.LiveUpdate`.
+
+        Updates are yielded oldest first. Up to 100 historical updates will
+        initially be returned.
+
+        Keyword arguments are passed to :func:`.stream_generator`.
+
+        For example, to retrieve all new updates made to the
+        ``"ta535s1hq2je"`` live thread, try:
+
+        .. code-block:: python
+
+            for live_update in reddit.live("ta535s1hq2je").stream.updates():
+                print(live_update.body)
+
+        To only retrieve new updates starting from when the stream is
+        created, pass ``skip_existing=True``:
+
+        .. code-block:: python
+
+            live_thread = reddit.live("ta535s1hq2je")
+            for live_update in live_thread.stream.updates(skip_existing=True):
+                print(live_update.author)
+
+        """
+        return stream_generator(self.live_thread.updates, **stream_options)
+
+
 class LiveUpdate(FullnameMixin, RedditBase):
     """An individual :class:`.LiveUpdate` object.
 
@@ -583,7 +652,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    necessarily comprehensive.
+    necessarily complete.
 
     ======================= ===================================================
     Attribute               Description
@@ -603,15 +672,15 @@ class LiveUpdate(FullnameMixin, RedditBase):
     _kind = "LiveUpdate"
 
     @cachedproperty
-    def contrib(self) -> _LiveUpdateContribution:
+    def contrib(self) -> "LiveUpdateContribution":
         """Provide an instance of :class:`.LiveUpdateContribution`.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           update = thread['7827987a-c998-11e4-a0b9-22000b6a88d2']
+           thread = reddit.live("ukaeu1ik4sw5")
+           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
            update.contrib  # LiveUpdateContribution instance
 
         """
@@ -624,7 +693,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         thread_id: Optional[str] = None,
         update_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -635,19 +704,19 @@ class LiveUpdate(FullnameMixin, RedditBase):
         provided.
 
         :param reddit: An instance of :class:`.Reddit`.
-        :param thread_id: A live thread ID, e.g., ``ukaeu1ik4sw5``.
+        :param thread_id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``.
         :param update_id: A live update ID, e.g.,
-            ``7827987a-c998-11e4-a0b9-22000b6a88d2``.
+            ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
 
         Usage:
 
         .. code-block:: python
 
-           update = LiveUpdate(reddit, 'ukaeu1ik4sw5',
-                               '7827987a-c998-11e4-a0b9-22000b6a88d2')
-           update.thread     # LiveThread(id='ukaeu1ik4sw5')
-           update.id         # '7827987a-c998-11e4-a0b9-22000b6a88d2'
-           update.author     # 'umbrae'
+           update = LiveUpdate(reddit, "ukaeu1ik4sw5",
+                               "7827987a-c998-11e4-a0b9-22000b6a88d2")
+           update.thread     # LiveThread(id="ukaeu1ik4sw5")
+           update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+           update.author     # "umbrae"
         """
         if _data is not None:
             # Since _data (part of JSON returned from reddit) have no
@@ -661,8 +730,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
             self.id = update_id
         else:
             raise TypeError(
-                "Either `thread_id` and `update_id`, or "
-                "`_data` must be provided."
+                "Either `thread_id` and `update_id`, or `_data` must be provided."
             )
 
     def __setattr__(self, attribute: str, value: Any):
@@ -672,9 +740,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
         super().__setattr__(attribute, value)
 
     def _fetch(self):
-        url = API_PATH["live_focus"].format(
-            thread_id=self.thread.id, update_id=self.id
-        )
+        url = API_PATH["live_focus"].format(thread_id=self.thread.id, update_id=self.id)
         other = self._reddit.get(url)[0]
         self.__dict__.update(other.__dict__)
         self._fetched = True
@@ -693,8 +759,8 @@ class LiveUpdateContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('ukaeu1ik4sw5')
-           update = thread['7827987a-c998-11e4-a0b9-22000b6a88d2']
+           thread = reddit.live("ukaeu1ik4sw5")
+           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
            update.contrib  # LiveUpdateContribution instance
            update.contrib.remove()
 
@@ -708,8 +774,8 @@ class LiveUpdateContribution:
 
          .. code-block:: python
 
-           thread = reddit.live('ydwwxneu7vsa')
-           update = thread['6854605a-efec-11e6-b0c7-0eafac4ff094']
+           thread = reddit.live("ydwwxneu7vsa")
+           update = thread["6854605a-efec-11e6-b0c7-0eafac4ff094"]
            update.contrib.remove()
 
         """
@@ -722,8 +788,8 @@ class LiveUpdateContribution:
 
         .. code-block:: python
 
-           thread = reddit.live('xyu8kmjvfrww')
-           update = thread['cb5fe532-dbee-11e6-9a91-0e6d74fabcc4']
+           thread = reddit.live("xyu8kmjvfrww")
+           update = thread["cb5fe532-dbee-11e6-9a91-0e6d74fabcc4"]
            update.contrib.strike()
 
         To check whether the update is stricken or not, use ``update.stricken``
