@@ -12,10 +12,10 @@ class InboxToggleableMixin:
 
         .. code-block:: python
 
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            comment.disable_inbox_replies()
 
-           submission = reddit.submission('8dmv8z')
+           submission = reddit.submission("8dmv8z")
            submission.disable_inbox_replies()
 
         .. seealso:: :meth:`~.enable_inbox_replies`
@@ -32,10 +32,10 @@ class InboxToggleableMixin:
 
         .. code-block:: python
 
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            comment.enable_inbox_replies()
 
-           submission = reddit.submission('8dmv8z')
+           submission = reddit.submission("8dmv8z")
            submission.enable_inbox_replies()
 
         .. seealso:: :meth:`~.disable_inbox_replies`
