@@ -17,11 +17,11 @@ class ReportableMixin:
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
-           submission.report('report reason')
+           submission = reddit.submission(id="5or86n")
+           submission.report("report reason")
 
-           comment = reddit.comment(id='dxolpyc')
-           comment.report('report reason')
+           comment = reddit.comment(id="dxolpyc")
+           comment.report("report reason")
 
         """
         self._reddit.post(
