@@ -1,7 +1,7 @@
 """Provide the Multireddit class."""
 import re
 from json import dumps
-from typing import Any, Dict, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -10,8 +10,8 @@ from .base import RedditBase
 from .redditor import Redditor
 from .subreddit import Subreddit, SubredditStream
 
-_Multireddit = TypeVar("_Multireddit")
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class Multireddit(SubredditListingMixin, RedditBase):
@@ -25,7 +25,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    necessarily comprehensive.
+    necessarily complete.
 
     ======================= ===================================================
     Attribute               Description
@@ -79,7 +79,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-           for comment in reddit.multireddit('spez', 'fun').stream.comments():
+           for comment in reddit.multireddit("spez", "fun").stream.comments():
                print(comment)
 
         Additionally, new submissions can be retrieved via the stream. In the
@@ -87,26 +87,22 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-           for submission in reddit.multireddit('bboe',
-                                                'games').stream.submissions():
+           for submission in reddit.multireddit("bboe",
+                                                "games").stream.submissions():
                print(submission)
 
         """
         return SubredditStream(self)
 
-    def __init__(self, reddit: Reddit, _data: Dict[str, Any]):
+    def __init__(self, reddit: "Reddit", _data: Dict[str, Any]):
         """Construct an instance of the Multireddit object."""
         self.path = None
         super().__init__(reddit, _data=_data)
         self._author = Redditor(reddit, self.path.split("/", 3)[2])
-        self._path = API_PATH["multireddit"].format(
-            multi=self.name, user=self._author
-        )
+        self._path = API_PATH["multireddit"].format(multi=self.name, user=self._author)
         self.path = "/" + self._path[:-1]  # Prevent requests for path
         if "subreddits" in self.__dict__:
-            self.subreddits = [
-                Subreddit(reddit, x["name"]) for x in self.subreddits
-            ]
+            self.subreddits = [Subreddit(reddit, x["name"]) for x in self.subreddits]
 
     def _fetch_info(self):
         return (
@@ -127,7 +123,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
-    def add(self, subreddit: Subreddit):
+    def add(self, subreddit: "Subreddit"):
         """Add a subreddit to this multireddit.
 
         :param subreddit: The subreddit to add to this multi.
@@ -136,19 +132,17 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            subreddit=reddit.subreddit('test')
-            reddit.multireddit('bboe', 'test').add(subreddit)
+            subreddit=reddit.subreddit("test")
+            reddit.multireddit("bboe", "test").add(subreddit)
 
         """
         url = API_PATH["multireddit_update"].format(
             multi=self.name, user=self._author, subreddit=subreddit
         )
-        self._reddit.request(
-            "PUT", url, data={"model": dumps({"name": str(subreddit)})}
-        )
+        self._reddit.put(url, data={"model": dumps({"name": str(subreddit)})})
         self._reset_attributes("subreddits")
 
-    def copy(self, display_name: Optional[str] = None) -> _Multireddit:
+    def copy(self, display_name: Optional[str] = None) -> "Multireddit":
         """Copy this multireddit and return the new multireddit.
 
         :param display_name: (optional) The display name for the copied
@@ -160,7 +154,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            reddit.multireddit('bboe', 'test').copy('testing')
+            reddit.multireddit("bboe", "test").copy("testing")
 
         """
         if display_name:
@@ -184,15 +178,15 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            reddit.multireddit('bboe', 'test').delete()
+            reddit.multireddit("bboe", "test").delete()
 
         """
         path = API_PATH["multireddit_api"].format(
             multi=self.name, user=self._author.name
         )
-        self._reddit.request("DELETE", path)
+        self._reddit.delete(path)
 
-    def remove(self, subreddit: Subreddit):
+    def remove(self, subreddit: "Subreddit"):
         """Remove a subreddit from this multireddit.
 
         :param subreddit: The subreddit to remove from this multi.
@@ -202,21 +196,20 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            subreddit=reddit.subreddit('test')
-            reddit.multireddit('bboe', 'test').remove(subreddit)
+            subreddit=reddit.subreddit("test")
+            reddit.multireddit("bboe", "test").remove(subreddit)
 
 
         """
         url = API_PATH["multireddit_update"].format(
             multi=self.name, user=self._author, subreddit=subreddit
         )
-        self._reddit.request(
-            "DELETE", url, data={"model": dumps({"name": str(subreddit)})}
-        )
+        self._reddit.delete(url, data={"model": dumps({"name": str(subreddit)})})
         self._reset_attributes("subreddits")
 
     def update(
-        self, **updated_settings: Union[str, List[Union[str, Subreddit]]]
+        self,
+        **updated_settings: Union[str, List[Union[str, Subreddit, Dict[str, str]]]]
     ):
         """Update this multireddit.
 
@@ -235,7 +228,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
             ``models pinup``, ``music``, ``news``, ``philosophy``, ``pictures
             and gifs``, ``science``, ``shopping``, ``sports``, ``style``,
             ``tech``, ``travel``, ``unusual stories``, ``video``, or ``None``.
-        :param key_color: RGB hex color code of the form ``#FFFFFF``.
+        :param key_color: RGB hex color code of the form ``"#FFFFFF"``.
         :param visibility: Can be one of: ``hidden``, ``private``, ``public``.
         :param weighting_scheme: Can be one of: ``classic``, ``fresh``.
 
@@ -243,7 +236,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            reddit.multireddit('bboe', 'test').update(display_name='testing')
+            reddit.multireddit("bboe", "test").update(display_name="testing")
 
         """
         if "subreddits" in updated_settings:
@@ -253,8 +246,5 @@ class Multireddit(SubredditListingMixin, RedditBase):
         path = API_PATH["multireddit_api"].format(
             multi=self.name, user=self._author.name
         )
-        response = self._reddit.request(
-            "PUT", path, data={"model": dumps(updated_settings)}
-        )
-        new = Multireddit(self._reddit, response["data"])
+        new = self._reddit.put(path, data={"model": dumps(updated_settings)})
         self.__dict__.update(new.__dict__)
