@@ -1,5 +1,5 @@
 """Provide the Submission class."""
-from typing import Any, Dict, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 from urllib.parse import urljoin
 
 from prawcore import Conflict
@@ -12,17 +12,18 @@ from ..listing.listing import Listing
 from ..listing.mixins import SubmissionListingMixin
 from .base import RedditBase
 from .mixins import FullnameMixin, ThingModerationMixin, UserContentMixin
+from .poll import PollData
 from .redditor import Redditor
 from .subreddit import Subreddit
 
-_Submission = TypeVar("_Submission")
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class SubmissionFlair:
     """Provide a set of functions pertaining to Submission flair."""
 
-    def __init__(self, submission: _Submission):
+    def __init__(self, submission: "Submission"):
         """Create a SubmissionFlair instance.
 
         :param submission: The submission associated with the flair functions.
@@ -42,9 +43,7 @@ class SubmissionFlair:
            choices = submission.flair.choices()
 
         """
-        url = API_PATH["flairselector"].format(
-            subreddit=self.submission.subreddit
-        )
+        url = API_PATH["flairselector"].format(subreddit=self.submission.subreddit)
         return self.submission._reddit.post(
             url, data={"link": self.submission.fullname}
         )["choices"]
@@ -65,8 +64,8 @@ class SubmissionFlair:
 
            choices = submission.flair.choices()
            template_id = next(x for x in choices
-                              if x['flair_text_editable'])['flair_template_id']
-           submission.flair.select(template_id, 'my custom value')
+                              if x["flair_text_editable"])["flair_template_id"]
+           submission.flair.select(template_id, "my custom value")
 
         """
         data = {
@@ -74,9 +73,7 @@ class SubmissionFlair:
             "link": self.submission.fullname,
             "text": text,
         }
-        url = API_PATH["select_flair"].format(
-            subreddit=self.submission.subreddit
-        )
+        url = API_PATH["select_flair"].format(subreddit=self.submission.subreddit)
         self.submission._reddit.post(url, data=data)
 
 
@@ -94,7 +91,7 @@ class SubmissionModeration(ThingModerationMixin):
 
     REMOVAL_MESSAGE_API = "removal_link_message"
 
-    def __init__(self, submission: _Submission):
+    def __init__(self, submission: "Submission"):
         """Create a SubmissionModeration instance.
 
         :param submission: The submission to moderate.
@@ -120,13 +117,12 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.mod.contest_mode(state=True)
 
         """
         self.thing._reddit.post(
-            API_PATH["contest_mode"],
-            data={"id": self.thing.fullname, "state": state},
+            API_PATH["contest_mode"], data={"id": self.thing.fullname, "state": state},
         )
 
     def flair(
@@ -151,8 +147,8 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
-           submission.mod.flair(text='PRAW', css_class='bot')
+           submission = reddit.submission(id="5or86n")
+           submission.mod.flair(text="PRAW", css_class="bot")
 
         """
         data = {
@@ -163,9 +159,7 @@ class SubmissionModeration(ThingModerationMixin):
         url = API_PATH["flair"].format(subreddit=self.thing.subreddit)
         if flair_template_id is not None:
             data["flair_template_id"] = flair_template_id
-            url = API_PATH["select_flair"].format(
-                subreddit=self.thing.subreddit
-            )
+            url = API_PATH["select_flair"].format(subreddit=self.thing.subreddit)
         self.thing._reddit.post(url, data=data)
 
     def nsfw(self):
@@ -178,16 +172,14 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.subreddit('test').submit('nsfw test',
-                                                        selftext='nsfw')
+           submission = reddit.subreddit("test").submit("nsfw test",
+                                                        selftext="nsfw")
            submission.mod.nsfw()
 
         .. seealso:: :meth:`~.sfw`
 
         """
-        self.thing._reddit.post(
-            API_PATH["marknsfw"], data={"id": self.thing.fullname}
-        )
+        self.thing._reddit.post(API_PATH["marknsfw"], data={"id": self.thing.fullname})
 
     def set_original_content(self):
         """Mark as original content.
@@ -201,8 +193,8 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.subreddit('test').submit('oc test',
-                                                        selftext='original')
+           submission = reddit.subreddit("test").submit("oc test",
+                                                        selftext="original")
            submission.mod.set_original_content()
 
         .. seealso:: :meth:`.unset_original_content`
@@ -227,7 +219,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.mod.sfw()
 
         .. seealso:: :meth:`~.nsfw`
@@ -247,19 +239,15 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.mod.spoiler()
 
         .. seealso:: :meth:`~.unspoiler`
 
         """
-        self.thing._reddit.post(
-            API_PATH["spoiler"], data={"id": self.thing.fullname}
-        )
+        self.thing._reddit.post(API_PATH["spoiler"], data={"id": self.thing.fullname})
 
-    def sticky(
-        self, state: bool = True, bottom: bool = True,
-    ):
+    def sticky(self, state: bool = True, bottom: bool = True):
         """Set the submission's sticky state in its subreddit.
 
         :param state: (boolean) True sets the sticky for the submission, false
@@ -279,7 +267,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.mod.sticky()
 
         """
@@ -287,9 +275,7 @@ class SubmissionModeration(ThingModerationMixin):
         if not bottom:
             data["num"] = 1
         try:
-            return self.thing._reddit.post(
-                API_PATH["sticky_submission"], data=data
-            )
+            return self.thing._reddit.post(API_PATH["sticky_submission"], data=data)
         except Conflict:
             pass
 
@@ -301,8 +287,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         """
         self.thing._reddit.post(
-            API_PATH["suggested_sort"],
-            data={"id": self.thing.fullname, "sort": sort},
+            API_PATH["suggested_sort"], data={"id": self.thing.fullname, "sort": sort},
         )
 
     def unset_original_content(self):
@@ -317,8 +302,8 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.subreddit('test').submit('oc test',
-                                                        selftext='original')
+           submission = reddit.subreddit("test").submit("oc test",
+                                                        selftext="original")
            submission.mod.unset_original_content()
 
         .. seealso:: :meth:`.set_original_content`
@@ -343,21 +328,17 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-           submission = reddit.subreddit('test').submit('not spoiler',
-                                                        selftext='spoiler')
+           submission = reddit.subreddit("test").submit("not spoiler",
+                                                        selftext="spoiler")
            submission.mod.unspoiler()
 
         .. seealso:: :meth:`~.spoiler`
 
         """
-        self.thing._reddit.post(
-            API_PATH["unspoiler"], data={"id": self.thing.fullname}
-        )
+        self.thing._reddit.post(API_PATH["unspoiler"], data={"id": self.thing.fullname})
 
 
-class Submission(
-    SubmissionListingMixin, UserContentMixin, FullnameMixin, RedditBase
-):
+class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, RedditBase):
     """A class for submissions to reddit.
 
     **Typical Attributes**
@@ -366,7 +347,7 @@ class Submission(
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    comprehensive in any way.
+    necessarily complete.
 
     =========================== ===============================================
     Attribute                   Description
@@ -394,6 +375,9 @@ class Submission(
     ``over_18``                 Whether or not the submission has been marked
                                 as NSFW.
     ``permalink``               A permalink for the submission.
+    ``poll_data``               A :class:`.PollData` object representing the
+                                data of this submission, if it is a poll
+                                submission.
     ``score``                   The number of upvotes for the submission.
     ``selftext``                The submissions' selftext - an empty string if
                                 a link post.
@@ -434,7 +418,7 @@ class Submission(
             submission_id = parts[-1]
             if "r" in parts:
                 raise InvalidURL(
-                    url, message="Invalid URL (subreddit, not submission): {}",
+                    url, message="Invalid URL (subreddit, not submission): {}"
                 )
         else:
             submission_id = parts[parts.index("comments") + 1]
@@ -444,7 +428,7 @@ class Submission(
         return submission_id
 
     @property
-    def _kind(self):
+    def _kind(self) -> str:
         """Return the class's kind."""
         return self._reddit.config.kinds["submission"]
 
@@ -466,7 +450,7 @@ class Submission(
 
         .. code-block:: python
 
-           submission.comment_sort = 'new'
+           submission.comment_sort = "new"
            comments = submission.comments.list()
 
         .. note:: The appropriate values for ``comment_sort`` include
@@ -495,8 +479,8 @@ class Submission(
 
            choices = submission.flair.choices()
            template_id = next(x for x in choices
-                              if x['flair_text_editable'])['flair_template_id']
-           submission.flair.select(template_id, 'my custom value')
+                              if x["flair_text_editable"])["flair_template_id"]
+           submission.flair.select(template_id, "my custom value")
 
         """
         return SubmissionFlair(self)
@@ -527,7 +511,7 @@ class Submission(
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         url: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -543,9 +527,7 @@ class Submission(
 
         """
         if (id, url, _data).count(None) != 2:
-            raise TypeError(
-                "Exactly one of `id`, `url`, or `_data` must be provided."
-            )
+            raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
         super().__init__(reddit, _data=_data)
         self.comment_limit = 2048
 
@@ -560,11 +542,13 @@ class Submission(
         self._comments_by_id = {}
 
     def __setattr__(self, attribute: str, value: Any):
-        """Objectify author, and subreddit attributes."""
+        """Objectify author, subreddit, and poll data attributes."""
         if attribute == "author":
             value = Redditor.from_data(self._reddit, value)
         elif attribute == "subreddit":
             value = Subreddit(self._reddit, value)
+        elif attribute == "poll_data":
+            value = PollData(self._reddit, value)
         super().__setattr__(attribute, value)
 
     def _chunk(self, other_submissions, chunk_size):
@@ -612,14 +596,14 @@ class Submission(
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.mark_visited()
 
         """
         data = {"links": self.fullname}
         self._reddit.post(API_PATH["store_visits"], data=data)
 
-    def hide(self, other_submissions: Optional[List[_Submission]] = None):
+    def hide(self, other_submissions: Optional[List["Submission"]] = None):
         """Hide Submission.
 
         :param other_submissions: When provided, additionally
@@ -630,7 +614,7 @@ class Submission(
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.hide()
 
         .. seealso:: :meth:`~.unhide`
@@ -639,7 +623,7 @@ class Submission(
         for submissions in self._chunk(other_submissions, 50):
             self._reddit.post(API_PATH["hide"], data={"id": submissions})
 
-    def unhide(self, other_submissions: Optional[List[_Submission]] = None):
+    def unhide(self, other_submissions: Optional[List["Submission"]] = None):
         """Unhide Submission.
 
         :param other_submissions: When provided, additionally
@@ -650,7 +634,7 @@ class Submission(
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.unhide()
 
         .. seealso:: :meth:`~.hide`
@@ -661,14 +645,14 @@ class Submission(
 
     def crosspost(
         self,
-        subreddit: Subreddit,
+        subreddit: "Subreddit",
         title: Optional[str] = None,
         send_replies: bool = True,
         flair_id: Optional[str] = None,
         flair_text: Optional[str] = None,
         nsfw: bool = False,
         spoiler: bool = False,
-    ) -> _Submission:
+    ) -> "Submission":
         """Crosspost the submission to a subreddit.
 
         .. note::
@@ -695,7 +679,7 @@ class Submission(
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            cross_post = submission.crosspost(subreddit="learnprogramming",
                                              send_replies=False)
 
