@@ -1,5 +1,5 @@
 """Provide the WikiPage class."""
-from typing import Any, Dict, Generator, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, Optional, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -7,9 +7,9 @@ from ..listing.generator import ListingGenerator
 from .base import RedditBase
 from .redditor import Redditor
 
-_WikiPage = TypeVar("_WikiPage")
-Reddit = TypeVar("Reddit")
-Subreddit = TypeVar("Subreddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
+    from .subreddit import Subreddit
 
 
 class WikiPageModeration:
@@ -20,10 +20,10 @@ class WikiPageModeration:
 
     .. code-block:: python
 
-        reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
+        reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
     """
 
-    def __init__(self, wikipage: _WikiPage):
+    def __init__(self, wikipage: "WikiPage"):
         """Create a WikiPageModeration instance.
 
         :param wikipage: The wikipage to moderate.
@@ -34,14 +34,14 @@ class WikiPageModeration:
     def add(self, redditor: Redditor):
         """Add an editor to this WikiPage.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance.
 
-        To add ``spez`` as an editor on the wikipage ``praw_test`` try:
+        To add ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
-           reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
+           reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
 
         """
         data = {"page": self.wikipage.name, "username": str(redditor)}
@@ -53,14 +53,14 @@ class WikiPageModeration:
     def remove(self, redditor: Redditor):
         """Remove an editor from this WikiPage.
 
-        :param redditor: A redditor name (e.g., ``spez``) or
+        :param redditor: A redditor name (e.g., ``"spez"``) or
             :class:`~.Redditor` instance.
 
-        To remove ``spez`` as an editor on the wikipage ``praw_test`` try:
+        To remove ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
-           reddit.subreddit('test').wiki['praw_test'].mod.remove('spez')
+           reddit.subreddit("test").wiki["praw_test"].mod.remove("spez")
 
         """
         data = {"page": self.wikipage.name, "username": str(redditor)}
@@ -94,7 +94,7 @@ class WikiPageModeration:
 
         .. code-block:: python
 
-           reddit.subreddit('test').wiki['praw_test'].mod.update(listed=False,
+           reddit.subreddit("test").wiki["praw_test"].mod.update(listed=False,
                                                                  permlevel=2)
 
         """
@@ -114,7 +114,7 @@ class WikiPage(RedditBase):
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    necessarily comprehensive.
+    necessarily complete.
 
     ======================= ===================================================
     Attribute               Description
@@ -137,9 +137,7 @@ class WikiPage(RedditBase):
 
     @staticmethod
     def _revision_generator(subreddit, url, generator_kwargs):
-        for revision in ListingGenerator(
-            subreddit._reddit, url, **generator_kwargs
-        ):
+        for revision in ListingGenerator(subreddit._reddit, url, **generator_kwargs):
             if revision["author"] is not None:
                 revision["author"] = Redditor(
                     subreddit._reddit, _data=revision["author"]["data"]
@@ -158,15 +156,15 @@ class WikiPage(RedditBase):
 
         .. code-block:: python
 
-            reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
+            reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
 
         """
         return WikiPageModeration(self)
 
     def __init__(
         self,
-        reddit: Reddit,
-        subreddit: Subreddit,
+        reddit: "Reddit",
+        subreddit: "Subreddit",
         name: str,
         revision: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -214,9 +212,7 @@ class WikiPage(RedditBase):
         self.__dict__.update(data)
         self._fetched = True
 
-    def edit(
-        self, content: str, reason: Optional[str] = None, **other_settings: Any
-    ):
+    def edit(self, content: str, reason: Optional[str] = None, **other_settings: Any):
         """Edit this WikiPage's contents.
 
         :param content: The updated Markdown content of the page.
@@ -228,53 +224,48 @@ class WikiPage(RedditBase):
 
         .. code-block:: python
 
-            page = next(iter(reddit.subreddit('test').wiki))
-            page.edit(content='test wiki page')
+            page = next(iter(reddit.subreddit("test").wiki))
+            page.edit(content="test wiki page")
 
         """
-        other_settings.update(
-            {"content": content, "page": self.name, "reason": reason}
-        )
+        other_settings.update({"content": content, "page": self.name, "reason": reason})
         self._reddit.post(
-            API_PATH["wiki_edit"].format(subreddit=self.subreddit),
-            data=other_settings,
+            API_PATH["wiki_edit"].format(subreddit=self.subreddit), data=other_settings,
         )
 
     def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
-        To view revision ``[ID]`` of ``praw_test`` in ``/r/test``:
+        To view revision ``[ID]`` of ``"praw_test"`` in ``/r/test``:
 
         .. code-block:: python
 
-           page = reddit.subreddit('test').wiki['praw_test'].revision('[ID]')
+           page = reddit.subreddit("test").wiki["praw_test"].revision("[ID]")
 
         """
-        return WikiPage(
-            self.subreddit._reddit, self.subreddit, self.name, revision
-        )
+        return WikiPage(self.subreddit._reddit, self.subreddit, self.name, revision)
 
     def revisions(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[_WikiPage, None, None]:
+    ) -> Generator["WikiPage", None, None]:
         """Return a :class:`.ListingGenerator` for page revisions.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        To view the wiki revisions for ``praw_test`` in ``/r/test`` try:
+        To view the wiki revisions for ``"praw_test"`` in ``/r/test`` try:
 
         .. code-block:: python
 
-           for item in reddit.subreddit('test').wiki['praw_test'].revisions():
+           for item in reddit.subreddit("test").wiki["praw_test"].revisions():
                print(item)
 
         To get :class:`.WikiPage` objects for each revision:
 
         .. code-block:: python
 
-           for item in reddit.subreddit('test').wiki['praw_test'].revisions():
-               print(item['page'])
+           for item in reddit.subreddit("test").wiki["praw_test"].revisions():
+               print(item["page"])
 
         """
         url = API_PATH["wiki_page_revisions"].format(
