@@ -1,5 +1,5 @@
 """Provide the Subreddits class."""
-from typing import Dict, Generator, List, Optional, Union
+from typing import Dict, Iterator, List, Optional, Union
 
 from ..const import API_PATH
 from . import Subreddit
@@ -17,7 +17,7 @@ class Subreddits(PRAWBase):
 
     def default(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Return a :class:`.ListingGenerator` for default subreddits.
 
         Additional keyword arguments are passed in the initialization of
@@ -29,7 +29,7 @@ class Subreddits(PRAWBase):
 
     def gold(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Return a :class:`.ListingGenerator` for gold subreddits.
 
         Additional keyword arguments are passed in the initialization of
@@ -41,7 +41,7 @@ class Subreddits(PRAWBase):
 
     def new(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Return a :class:`.ListingGenerator` for new subreddits.
 
         Additional keyword arguments are passed in the initialization of
@@ -53,7 +53,7 @@ class Subreddits(PRAWBase):
 
     def popular(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Return a :class:`.ListingGenerator` for popular subreddits.
 
         Additional keyword arguments are passed in the initialization of
@@ -79,15 +79,11 @@ class Subreddits(PRAWBase):
         """
         if not isinstance(subreddits, list):
             raise TypeError("subreddits must be a list")
-        if omit_subreddits is not None and not isinstance(
-            omit_subreddits, list
-        ):
+        if omit_subreddits is not None and not isinstance(omit_subreddits, list):
             raise TypeError("omit_subreddits must be a list or None")
 
         params = {"omit": self._to_list(omit_subreddits or [])}
-        url = API_PATH["sub_recommended"].format(
-            subreddits=self._to_list(subreddits)
-        )
+        url = API_PATH["sub_recommended"].format(subreddits=self._to_list(subreddits))
         return [
             Subreddit(self._reddit, sub["sr_name"])
             for sub in self._reddit.get(url, params=params)
@@ -95,7 +91,7 @@ class Subreddits(PRAWBase):
 
     def search(
         self, query: str, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Return a :class:`.ListingGenerator` of subreddits matching ``query``.
 
         Subreddits are searched by both their title and description.
@@ -125,11 +121,7 @@ class Subreddits(PRAWBase):
         """
         result = self._reddit.post(
             API_PATH["subreddits_name_search"],
-            data={
-                "include_over_18": include_nsfw,
-                "exact": exact,
-                "query": query,
-            },
+            data={"include_over_18": include_nsfw, "exact": exact, "query": query},
         )
         return [self._reddit.subreddit(x) for x in result["names"]]
 
@@ -142,13 +134,11 @@ class Subreddits(PRAWBase):
         result = self._reddit.get(
             API_PATH["subreddits_by_topic"], params={"query": query}
         )
-        return [
-            self._reddit.subreddit(x["name"]) for x in result if x.get("name")
-        ]
+        return [self._reddit.subreddit(x["name"]) for x in result if x.get("name")]
 
     def stream(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> Generator[Subreddit, None, None]:
+    ) -> Iterator[Subreddit]:
         """Yield new subreddits as they are created.
 
         Subreddits are yielded oldest first. Up to 100 historical subreddits
